import { useState } from 'react';
import Taro from '@tarojs/taro';
import { View, Form } from '@tarojs/components';
import Schema from 'async-validator';
import FormError from './FormError';

// 支持验证规则的表单
// 验证规则同 ant design 一致
export default function (props) {
  const { onSubmit, onError, rules, ...leftProps } = props

  const [errMsg, setErrMsg] = useState()

  const handleSubmit = (e) => {
    const formData = Object.assign({}, e.detail.value)
    console.log('--表单内容--', formData)
    if (!rules) {
      if (onSubmit) {
        onSubmit(formData)
      }
      return;
    }

    const validator = new Schema(rules);
    validator.validate(formData).then(() => {
      if (onSubmit) {
        onSubmit(formData)
      }
    }).catch(({ errors }) => {
      if (onError) {
        onError(errors)
      } else {
        setErrMsg(errors[0].message)
      }
    })
  }

  return (
    <View>
      <FormError error={errMsg} />
      <Form {...leftProps} onSubmit={handleSubmit}>
        {props.children}
      </Form>
    </View>
  )
}
