import { View, Image, ScrollView } from '@tarojs/components'
import Taro, { useRouter } from '@tarojs/taro';
import { useEffect, useState } from 'react';
import RatioItem from '@/components/RatioItem';
import withBasic from '@/layouts/withBasic'
import PageLoading from '@/components/PageLoading'
import { getDogCardInfo } from '@/services/dogAPI';
import NoData from '../../components/NoData';

import './style.less'
const CardDetailPage = (props) => {
  const router = useRouter()
  const cardNo = router.params.cardno
  const [applicationInfoDate, setApplicationInfoDate] = useState()
  useEffect(() => {
    if (cardNo) {
      getDogCardInfo(cardNo, true).then((e) => {
        setApplicationInfoDate(e)

      }).catch(() => {

      })
    } else {
      Taro.showToast({
        title: '错误',
        icon: 'error',
        duration: 2000
      })
    }
    return;
  }, [cardNo])
  const lookImage = (res) => {
    Taro.previewImage({
      current: res, // 当前显示图片的http链接
      urls: [res] // 需要预览的图片http链接列表
    })
  }

  return (

    <>
      {
        !applicationInfoDate ? <NoData title='暂无此狗狗证件详情哦~' />
          :
          <View className='dogCardDetail'>
            <View className='card'>
              <View className='title'>电&nbsp;&nbsp;&nbsp;子&nbsp;&nbsp;&nbsp;版&nbsp;&nbsp;&nbsp;犬&nbsp;&nbsp;&nbsp;证</View>
              <View className='body'>
                <View className='cardLeft'>
                  {
                    !applicationInfoDate?.isOrg ? <></> :
                      <View className='cell'>
                        <View className='lable'>是否企业</View>：
                        <View className='content'>{applicationInfoDate?.orgName}</View>
                      </View>
                  }

                  <View className='cell'>
                    <View className='lable'>犬主</View>：
                    <View className='content'>{applicationInfoDate?.personName}</View>
                  </View>
                  <View className='cell'>
                    <View className='lable'>电话</View>：
                    <View className='content'>{applicationInfoDate?.phone}</View>
                  </View>
                  <View className='cell'>
                    <View className='lable'>犬名</View>：
                    <View className='content'>{applicationInfoDate?.petName}</View>
                  </View>
                  <View className='cell'>
                    <View className='lable'>性别</View>：
                    <View className='content'>{applicationInfoDate?.petSex == 1 ? '雄' : '雌'}</View>
                  </View>
                </View>
                <View className='cardRight'>
                  <RatioItem ratio='109:151'>
                    <Image
                      style={{ width: '100%', height: '100%' }}
                      src={applicationInfoDate?.petImg1}
                    ></Image>
                  </RatioItem>
                </View >
              </View >
              <View className='cell' style={{ marginTop: '0' }}>
                <View className='lable'>状态</View>：
                <View className={['state', 'color' + applicationInfoDate?.status]}>{applicationInfoDate?.status == 1 ? '正常' : applicationInfoDate?.status == 2 ? '挂失' : '过期'}</View>
              </View>
              <View className='cell'>
                <View className='lable'>犬种</View>：
                <View className='content'>{applicationInfoDate?.petType}</View>
              </View>
              {
                applicationInfoDate?.criminalInfo == null ? <></> :

                  <View className='cell'>
                    <View className='lable'>伤人信息</View>：
                    {/* <View className='content'>{applicationInfoDate?.criminalInfo}</View> */}
                    <Image onClick={() => { lookImage(applicationInfoDate?.criminalInfo) }} src={applicationInfoDate?.criminalInfo} style={{ width: '90px', height: '90px' }} />

                  </View>
              }
              {
                applicationInfoDate?.penaltyInfo == null ? <></> :

                  <View className='cell'>
                    <View className='lable'>伤人信息</View>：
                    {/* <View className='content'>{applicationInfoDate?.criminalInfo}</View> */}
                    <Image onClick={() => { lookImage(applicationInfoDate?.penaltyInfo) }} src={applicationInfoDate?.penaltyInfo} style={{ width: '90px', height: '90px' }} />
                  </View>
              }
              <View className='cell'>
                <View className='lable'>毛色</View>：
                <View className='content'>{applicationInfoDate?.petColor}</View>
              </View>
              <View className='cell'>
                <View className='lable'>证件号</View>：
                <View className='content'>{applicationInfoDate?.cardNo}</View>
              </View>
              <View className='cell'>
                <View className='lable'>有效期</View>：
                <View className='content'>{applicationInfoDate?.startDate}~{applicationInfoDate?.expireDate}</View>
              </View>
              <View className='cell'>
                <View className='lable'>住址</View>：
                <View className='content'>{applicationInfoDate?.address}</View>
              </View>
            </View >
          </View >
      }

    </>
  )
}

export default withBasic(CardDetailPage, PageLoading)
