import { useEffect, useState } from 'react'
import { View, ScrollView, Text } from '@tarojs/components'
import Taro from '@tarojs/taro'
import Banner from '@/components/Banner'
import Notice from '@/components/Notice'
import PageLoading from '@/components/PageLoading'
import withBasic from '@/layouts/withBasic'

import { useModel } from '@/store'
import { getApplicationList, getBannerList, getDogCardList } from '@/services/dogAPI'
import MenuItem from './components/MenuItem'

import './style.less'
import { getBanner, getNoticeList } from '../../services/dogAPI'

const pt16 = {
  paddingTop: '16px'
}

const ml16 = {
  marginLeft: '16px'
}

const IndexPage = (props) => {
  const { pets, cards, setCards } = useModel('userData')
  const [totalApplyNum, setTotalApplyNum] = useState(0)
  const [noticeList, setNoticeList] = useState([])
  const [bannerList, setBannerList] = useState([])

  useEffect(() => {
    Taro.showShareMenu({
      withShareTicket: true
    })
    getNoticeList({ pageSize: 5 }).then((res) => {
      setNoticeList(res.records)
    })

    getApplicationList().then(res => {
      setTotalApplyNum(res.total)
    })

    getBannerList().then(res => {
      setBannerList(res)
    })
    getDogCardList().then(res => {
      setCards(res.records)
    })
  }, [])

  const goNoticeList = (e) => {
    Taro.navigateTo({ url: '/pages/noticeList/index' })
  }
  const goDetail = (id) => {
    Taro.navigateTo({ url: `/pages/noticeInfo/index?id=${id}` })
  }

  return (
    <>
      <View className='index-page-box'>
        <View style={{ padding: '16px', boxSizing: 'border-box' }}>
          <Banner list={bannerList} />
        </View>
        <View className='border-card-group'>
          <View class='weui-flex'>
            <View class='weui-flex__item'>
              <MenuItem
                icon='dog'
                title='办证申请'
                subtitle='Registration application'
                to='/pages/setDogLicense/index?type=first'
              >
              </MenuItem>
            </View>
            <View class='weui-flex__item' style={ml16}>
              <MenuItem
                title='证件查看'
                subtitle='Certificate check'
                icon='certificate'
                to='/pages/dogLicenseList/index'
              >
                <View>您有<Text>{cards ? cards.length : 0}</Text>证件可查看</View>
              </MenuItem>
            </View>
          </View>
          <View class='weui-flex' style={pt16}>
            <View class='weui-flex__item'>
              <MenuItem
                title='个人中心'
                subtitle='Personal center'
                ratio='470:452'
                icon='personal'
                to='/pages/main/index'
              >
                <View>您有<Text>{totalApplyNum}</Text>条办证申请记录</View>
              </MenuItem>
            </View>
            <View class='weui-flex__item' style={ml16}>
              <MenuItem
                title='证件续期'
                subtitle='Certificate renewal'
                ratio='470:206'
                icon='renewal'
                iconSize={72}
                to='/pages/setDogLicense/index?type=renewal'
              />

              <View style={pt16}>
                <MenuItem
                  title='证件补办'
                  subtitle='Replacement certificate'
                  ratio='470:206'
                  icon='replacement'
                  iconSize={72}
                  to='/pages/setDogLicense/index?type=reissue'
                />
              </View>
            </View>
          </View>
        </View>

        <View className='message-box'>
          <Notice NoticeList={noticeList} onMoreClick={goNoticeList} onClick={goDetail} />

        </View>
      </View>
    </>
  )
}

export default withBasic(IndexPage, PageLoading)
