import { ScrollView, View } from '@tarojs/components'
import Taro, { reLaunch, useRouter } from '@tarojs/taro';
import { useState, useEffect } from 'react';
import { getOrder } from '@/services/dogAPI';
import Button from '../../components/Button';
import './style.less'

export default (props) => {
  const value = useRouter();
  const { id } = value.params
  const [orderInfo, setOrderInfo] = useState()
  const [payLoading, setPayLoading] = useState(false)
  useEffect(() => {
    if (id) {
      setPayLoading(true)
      getOrder(id).then((e) => {
        console.log('e', e);
        setOrderInfo(e)
        setPayLoading(false)

      })
    }

  }, [id])

  const pay = (params) => {
    Taro.hideLoading()
    Taro.requestPayment({
      ...orderInfo.prepay,
      package: orderInfo.prepay.packageValue,
      success: () => {
        Taro.showToast({
          title: "支付成功",
          icon: "success",
          duration: 1000,
        }).then(() => {
          console.log('支付成功',);
          setTimeout(() => {
            Taro.reLaunch({
              url: '/pages/ApplicationList/index'
            })
          }, 400)
        })
      },
      fail: (e) => {
        Taro.showToast({
          title: "支付失败",
          icon: "none",
          duration: 2000,
        });
        console.log('支付失败', e);

      },
    })
  }

  return (
    <>
      {
        payLoading ? <mp-loading extClass="page-loading-circle" type="circle" show={payLoading} /> :
          <>
            <View className='payPageBox'>
              <View className='payPageBox-payItemBox'>
                <View className='payPageBox-payItemBox-left'></View>
                <View className='payPageBox-payItemBox-content'>订单号： <View>{orderInfo?.order?.orderNo}</View></View>
              </View>
              <View className='payPageBox-payItemBox'>
                <View className='payPageBox-payItemBox-leftText'>下单时间： <View>{orderInfo?.order?.createDate}</View></View>
              </View>
              <View className='payPageBox-payItemBox'>
                <View className='payPageBox-payItemBox-leftText'>工本费： <View>{(orderInfo?.order?.productionCost / 100).toFixed(2)}</View>元</View>
              </View>
              <View className='payPageBox-payItemBox'>
                <View className='payPageBox-payItemBox-leftText'>快递费： <View>{(orderInfo?.order?.expressFee / 100).toFixed(2)}</View>元</View>
              </View>
              <View className='payPageBox-payItemBox'>
                <View className='payPageBox-payItemBox-leftText'>总金额： <View style={{ color: 'red' }}>{(orderInfo?.order?.charges / 100).toFixed(2)}</View>元</View>
              </View>
            </View>
            <Button title='支付' onClick={pay} />
          </>
      }

    </>
  )
}