
import { useEffect } from 'react';
import Taro, { useRouter } from '@tarojs/taro';
import withBasic from '@/layouts/withBasic'
import PageLoading from '@/components/PageLoading'
import { getQRCode } from '@/services/qrcode';

const QRCodePage = (props) => {
  const router = useRouter()
  const scene = router?.params?.scene

  useEffect(() => {
    if (scene) {
      // scene 实际上是后台小程序码表的主键
      getQRCode(scene).then(res => {
        if (!res || !res.scene) {
          console.error('QRCode has no scene param')
          Taro.reLaunch({ url: '/pages/index/index' })
          return;
        }

        const sceneObj = typeof res.scene === 'string' ? JSON.parse(res.scene) : res.scene
        const { page, queryStr } = sceneObj
        const url = queryStr ? `/${page}?${queryStr}` : `/${page}`
        Taro.reLaunch({ url })
      }).catch(err => {
        console.error(err)
        Taro.reLaunch({ url: '/pages/index/index' })
      })
    }
  }, [scene])

  return <PageLoading />
}

export default withBasic(QRCodePage, PageLoading)
