import { View, Picker, Input, ScrollView } from '@tarojs/components'
import Taro, { useRouter } from '@tarojs/taro';
import { useState, useEffect } from 'react';
import Form from '@/components/Form';
import FormItem from '@/components/Form/FormItem'
import { addDogInfo, getDogInfo, getDogType, setDogInfo } from '@/services/dogAPI';
import { useModel } from '@/store'
import { handleFile } from '@/utils/request';
import Button from '../../components/Button';
import './style.less'

const rules = {
  name: [{ required: true, message: '请填写狗狗名称' }],
  sex: [{ type: 'number', required: true, message: '请填写狗狗性别' }],
  birthday: [{ required: true, message: '请选择狗狗生日' }],
  color: [{ required: true, message: '请选择狗狗毛色' }],
  petType: [{ required: true, message: '请选择犬种类别' }],
  image: [{ required: true, message: '请上传狗狗照片' }],
}

export default (props) => {
  const { dogs, setDogs } = useModel('userData')
  const [dogType, setDogType] = useState([])
  const [formData, setFormData] = useState()

  const router = useRouter()
  const petId = router.params.petId

  useEffect(() => {
    getDogType().then((res) => {
      const DogTypelist = res.content.split(',').map(x => ({ text: x, value: x }))
      setDogType(DogTypelist)
    })

    if (petId) {
      getDogInfo(petId).then((e) => {
        setFormData(e)
      })
    }
    return;
  }, [petId])

  const formSubmit = (value) => {
    console.log('formVlue', value);
    if (petId) {
      console.log('y ID',);
      setDogInfo(petId, value).then((e) => {
        console.log("🚀 ~ 修改数据", value)
        Taro.showToast({
          title: '修改成功',
          icon: 'none',
          duration: 1000
        })
        setTimeout(() => {
          Taro.navigateBack({
            delta: 1
          })
        }, 600);
      })
    } else {
      console.log('没有ID',);

      addDogInfo(value).then((e) => {
        console.log("🚀 修改前s", dogs)
        // setDogs((dogs || [e]))
        setDogs((dogs || []).concat(e))

        console.log("🚀 ~ 保存成功数据", value, e)


        Taro.showToast({
          title: '保存成功',
          icon: 'none',
          duration: 1000
        })
        setTimeout(() => {
          Taro.navigateBack({
            delta: 1
          })
        }, 600);

      })
    }
  }

  const dogSex = [
    {
      value: 1,
      text: '雄',
    },
    {
      value: 2,
      text: '雌',
    },
  ]

  const handleBirthday = (e) => {
    const birthday = e.detail.value
    setFormData({ ...formData, birthday: birthday })
    console.log(' birthday: birthday', formData);

  }

  return (
    <>
      <View class='page' >
        <Form rules={rules} onSubmit={formSubmit}>
          <FormItem title='狗狗名称' required>
            <Input name='name' value={formData?.name} placeholder='请输入狗狗名称' onInput={(e) => { setFormData({ ...formData, name: e.detail.value }) }} />
          </FormItem>
          <FormItem title='狗狗性别' required>
            <s-picker name='sex' rangeKey='text' rangeValue='value' range={dogSex} value={formData?.sex} />
          </FormItem>
          <FormItem title='犬种' required>
            <s-picker name='petType' rangeKey='text' rangeValue='value' range={dogType} value={formData?.petType} />
          </FormItem>
          <FormItem title='生日' required>
            <Picker name='birthday' mode='date' onChange={handleBirthday} value={formData?.birthday}>
              {formData?.birthday ? (
                <View className='picker'>
                  {formData?.birthday}
                </View>
              ) : <View style={{ color: '#858585' }}>请选择...</View>
              }
            </Picker>
          </FormItem>
          <FormItem title='毛色' required>
            <Input name='color' placeholder='请输入毛色' value={formData?.color} onInput={(e) => { setFormData({ ...formData, color: e.detail.value }) }} />
          </FormItem>
          <FormItem title='狗狗照片' required>
            <uploader name='image' value={formData?.image} onFile={handleFile} />
          </FormItem>
          <Button title='添加' />
        </Form>
      </View>
    </>
  )
}
